from PySide2.QtWidgets import QMainWindow, QApplication, QLabel, QWidget, QPushButton
from PySide2.QtGui import QPixmap, QImage
from PySide2.QtCore import QSize, Qt



class QImageWidget(QLabel):

    def __init__(self, parent, img=''):
        super().__init__(parent)
        self.img = img
        self.setImage(img)

    def setImage(self, img):
        self.img = img
        image = QPixmap(img)
        if img:
            self.pixmap = QPixmap(img)
            self.setPixmap(self.pixmap)
            self.resize(QSize(image.size()))
        self.image = img
        self.pixmap = image

    def setScale(self, size, aspectRatioMode=Qt.IgnoreAspectRatio):
        # Qt.IgnoreAspectRatio, Qt.KeepAspectRatio, Qt.KeepAspectRatioByExpanding
        self.setImage(self.img)
        self.pixmap = self.pixmap.scaled(*size, aspectRatioMode)
        self.setPixmap(self.pixmap)
        self.resize(QSize(*size))



from PyQt5.QtWidgets import QMainWindow, QApplication, QLabel, QWidget, QPushButton
from PyQt5.QtGui import QPixmap, QImage
from PyQt5.QtCore import QSize, Qt

'''from PySide2.QtWidgets import QMainWindow, QApplication, QLabel, QWidget, QPushButton
from PySide2.QtGui import QPixmap, QImage
from PySide2.QtCore import QSize, Qt'''



class QImageWidget(QLabel):

    def __init__(self, parent, img=''):
        super().__init__(parent)
        self.img = img
        self.setImage(img)

    def setImage(self, img):
        self.img = img
        image = QPixmap(img)
        if img:
            self.pixmap = QPixmap(img)
            self.setPixmap(self.pixmap)
            self.resize(QSize(image.size()))
        self.image = img
        self.pixmap = image

    def setScale(self, size, aspectRatioMode=Qt.IgnoreAspectRatio):
        # Qt.IgnoreAspectRatio, Qt.KeepAspectRatio, Qt.KeepAspectRatioByExpanding
        self.setImage(self.img)
        self.pixmap = self.pixmap.scaled(*size, aspectRatioMode)
        self.setPixmap(self.pixmap)
        self.resize(QSize(*size))



from setuptools import setup, find_packages

setup(
    name='QImageWidget',
    version='1.0.1',
    description='A PyQt5/PySide2 widget for displaying images',
    author='Render666',
    author_email='hackermananonimous228666@gmail.com',
    url='https://github.com/RedEnder666/QImageWidget',
    packages=find_packages(),
    install_requires=[
        'PyQt5>=5.15.4',
        'PySide2>=5.15.4'
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
